@@ -1,5 +1,4 @@
 """Define a SimpliSafe account."""
-# pylint: disable=protected-access
 import logging
 from datetime import datetime, timedelta
 from typing import Dict, Optional, Type, TypeVar
@@ -8,10 +7,12 @@ from uuid import UUID, uuid4
 from aiohttp import BasicAuth, ClientSession
 from aiohttp.client_exceptions import ClientError
 
-from .errors import InvalidCredentialsError, RequestError
-from .system import System, SystemV2, SystemV3  # noqa
+from simplipy.errors import InvalidCredentialsError, RequestError
+from simplipy.system import System
+from simplipy.system.v2 import SystemV2
+from simplipy.system.v3 import SystemV3
 
-_LOGGER = logging.getLogger(__name__)
+_LOGGER: logging.Logger = logging.getLogger(__name__)
 
 DEFAULT_USER_AGENT: str = "SimpliSafe/2105 CFNetwork/902.2 Darwin/17.7.0"
 DEFAULT_AUTH_USERNAME: str = "{0}.2074.0.0.com.simplisafe.mobile"
@@ -32,10 +33,10 @@ class API:  # pylint: disable=too-many-instance-attributes
         self._access_token: str = ""
         self._access_token_expire: Optional[datetime] = None
         self._actively_refreshing: bool = False
-        self._email: Optional[str] = None
         self._refresh_token: str = ""
         self._uuid: UUID = uuid4()
         self._websession: ClientSession = websession
+        self.email: Optional[str] = None
         self.refresh_token_dirty: bool = False
         self.user_id: Optional[str] = None
 
@@ -62,9 +63,9 @@ class API:  # pylint: disable=too-many-instance-attributes
     ) -> ApiType:
         """Create an API object from a email address and password."""
         klass = cls(websession)
-        klass._email = email
+        klass.email = email
 
-        await klass._authenticate(
+        await klass.authenticate(
             {"grant_type": "password", "username": email, "password": password}
         )
 
@@ -76,10 +77,10 @@ class API:  # pylint: disable=too-many-instance-attributes
     ) -> ApiType:
         """Create an API object from a refresh token."""
         klass = cls(websession)
-        await klass._refresh_access_token(refresh_token)
+        await klass.refresh_access_token(refresh_token)
         return klass
 
-    async def _authenticate(self, payload_data: dict) -> None:
+    async def authenticate(self, payload_data: dict) -> None:
         """Request token data and parse it."""
         token_resp: dict = await self.request(
             "post",
@@ -101,18 +102,6 @@ class API:  # pylint: disable=too-many-instance-attributes
         auth_check_resp: dict = await self.request("get", "api/authCheck")
         self.user_id = auth_check_resp["userId"]
 
-    async def _refresh_access_token(self, refresh_token: str) -> None:
-        """Regenerate an access token."""
-        await self._authenticate(
-            {
-                "grant_type": "refresh_token",
-                "username": self._email,
-                "refresh_token": refresh_token,
-            }
-        )
-
-        self._actively_refreshing = False
-
     async def get_systems(self) -> Dict[str, System]:
         """Get systems associated to this account."""
         subscription_resp: dict = await self.get_subscription_data()
@@ -137,15 +126,27 @@ class API:  # pylint: disable=too-many-instance-attributes
 
         return subscription_resp
 
+    async def refresh_access_token(self, refresh_token: str) -> None:
+        """Regenerate an access token."""
+        await self.authenticate(
+            {
+                "grant_type": "refresh_token",
+                "username": self.email,
+                "refresh_token": refresh_token,
+            }
+        )
+
+        self._actively_refreshing = False
+
     async def request(
         self,
         method: str,
         endpoint: str,
         *,
-        headers: dict = None,
-        params: dict = None,
-        data: dict = None,
-        json: dict = None,
+        headers: Optional[dict] = None,
+        params: Optional[dict] = None,
+        data: Optional[dict] = None,
+        json: Optional[dict] = None,
         **kwargs,
     ) -> dict:
         """Make a request."""
@@ -155,9 +156,7 @@ class API:  # pylint: disable=too-many-instance-attributes
             and not self._actively_refreshing
         ):
             self._actively_refreshing = True
-            await self._refresh_access_token(self._refresh_token)
-
-        url: str = f"{URL_BASE}/{endpoint}"
+            await self.refresh_access_token(self._refresh_token)
 
         if not headers:
             headers = {}
@@ -168,7 +167,7 @@ class API:  # pylint: disable=too-many-instance-attributes
         try:
             async with self._websession.request(
                 method,
-                url,
+                f"{URL_BASE}/{endpoint}",
                 headers=headers,
                 params=params,
                 data=data,
@@ -180,8 +179,9 @@ class API:  # pylint: disable=too-many-instance-attributes
         except ClientError as err:
             if "401" in str(err):
                 if self._actively_refreshing:
-                    _LOGGER.error("Refresh token was unsuccessful on 401")
-                    raise InvalidCredentialsError
+                    raise InvalidCredentialsError(
+                        "Repeated 401s despite refreshing access token"
+                    )
                 if self._refresh_token:
                     _LOGGER.info("401 detected; attempting refresh token")
                     self._access_token_expire = datetime.now()
@@ -194,11 +194,13 @@ class API:  # pylint: disable=too-many-instance-attributes
                         json=json,
                         **kwargs,
                     )
-                raise InvalidCredentialsError
+                raise InvalidCredentialsError("Invalid username/password")
             if "403" in str(err):
                 if self.user_id:
                     _LOGGER.info("Endpoint unavailable in plan: %s", endpoint)
                     return {}
-                raise InvalidCredentialsError
+                raise InvalidCredentialsError(
+                    f"User does not have permission to access {endpoint}"
+                )
 
             raise RequestError(f"Error requesting data from {endpoint}: {err}")
